@@ -25,7 +25,9 @@ if "windows" == platform.system().lower():
 
 
 # Instantiate and connect to the device; see demo1.py
-device = Device()
+cLibVersion = input("Please enter cLibVersion: ")
+port = input("Please enter the device port: ")
+device = Device(port=port, cLibVersion=cLibVersion)
 device.open()
 
 
@@ -48,7 +50,7 @@ data = device.read()
 # some offset. The motor position is given in "ticks", and the
 # conversion between ticks and degrees depends on the device. For an
 # actpack, the conversion is 350 degrees = 16384 ticks
-offset = 10000
+offset = 1000
 pos0 = data["mot_ang"]
 positions = [pos0, pos0 + offset]
 
